aboutsummaryrefslogtreecommitdiff
path: root/azalea-auth/src
diff options
context:
space:
mode:
Diffstat (limited to 'azalea-auth/src')
-rwxr-xr-xazalea-auth/src/game_profile.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/azalea-auth/src/game_profile.rs b/azalea-auth/src/game_profile.rs
index 31650754..af00712d 100755
--- a/azalea-auth/src/game_profile.rs
+++ b/azalea-auth/src/game_profile.rs
@@ -1,10 +1,10 @@
use std::collections::HashMap;
-use azalea_buf::McBuf;
+use azalea_buf::AzBuf;
use serde::{Deserialize, Serialize};
use uuid::Uuid;
#[derive(McBuf, Debug, Clone, Default, Eq, PartialEq)]
pub struct GameProfile {
/// The UUID of the player.
pub uuid: Uuid,
@@ -43,7 +43,7 @@ impl From<SerializableGameProfile> for GameProfile {
}
}
#[derive(McBuf, Debug, Clone, Eq, PartialEq)]
pub struct ProfilePropertyValue {
pub value: String,
pub signature: Option<String>,
@@ -1,10 +1,10 @@
use serde::{Deserialize, Serialize};
use uuid::Uuid;
-#[derive(McBuf, Debug, Clone, Default, Eq, PartialEq)]
+#[derive(AzBuf, Debug, Clone, Default, Eq, PartialEq)]
pub struct GameProfile {
/// The UUID of the player.
@@ -43,7 +43,7 @@ impl From<SerializableGameProfile> for GameProfile {
}
}
-#[derive(McBuf, Debug, Clone, Eq, PartialEq)]
+#[derive(AzBuf, Debug, Clone, Eq, PartialEq)]
pub struct ProfilePropertyValue {
pub value: String,